
{*******************************************************}
{                                                       }
{       RichView                                        }
{       Demo: viewing dropped files                     }
{                                                       }
{       Copyright (c) Sergey Tkachenko                  }
{       svt@trichview.com                               }
{       http://www.trichview.com                        }
{                                                       }
{*******************************************************}

unit Unit1;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, ExtCtrls, StdCtrls, Buttons, RVStyle, RVScroll, RichView, RVEdit,
  MultiDropTarget, ViewFrm, {GifImage, PNGImage,} CRVData;

type
  { This form is created at the bottom right corner of the screen }
  TForm1 = class(TForm)
    RVStyle1: TRVStyle;
    Image1: TImage;
    procedure FormCreate(Sender: TObject);
  private
    { Private declarations }
    frmView: TfrmView;
    rv: TRichViewTarget;    
    procedure OleEnter(Sender: TObject);
    procedure OleLeave(Sender: TObject);
    procedure OleDropNotAccepted(Sender: TObject);
    procedure OleBeforeDrop(Sender: TCustomRichView; X, Y: Integer;
      var CanDropHere: Boolean);
    procedure OleAfterDrop(Sender: TCustomRichView; X, Y: Integer;
      Format: TRVDragDropFormat; const Title: String);
    procedure OleDragOver(Sender: TCustomRichView; X, Y: Integer;
      var CanDropHere: Boolean);
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.dfm}

procedure TForm1.FormCreate(Sender: TObject);
begin
  rv := TRichViewTarget.Create(Self);
  rv.Parent := Self;
  rv.Style := RVStyle1;
  rv.BackgroundStyle := bsCentered;
  rv.BackgroundBitmap := Image1.Picture.Bitmap;
  rv.BorderStyle := bsNone;
  rv.Width := Image1.Picture.Bitmap.Width;
  rv.Height := Image1.Picture.Bitmap.Height;
  rv.OnOleDragEnter := OleEnter;
  rv.OnOleDragLeave := OleLeave;
  rv.OnOleBeforeDrop := OleBeforeDrop;
  rv.OnOleAfterDrop := OleAfterDrop;
  rv.OnOleDragOver := OleDragOver;
  rv.OnOleDropNotAccepted := OleDropNotAccepted;

  ClientWidth := rv.Width;
  ClientHeight := rv.Height;
  Left := Screen.WorkAreaLeft+Screen.WorkAreaWidth-Width;
  Top  := Screen.WorkAreaTop+Screen.WorkAreaHeight-Height;
end;


procedure TForm1.OleBeforeDrop(Sender: TCustomRichView; X, Y: Integer;
  var CanDropHere: Boolean);
begin
  AlphaBlendValue := 255;
  if frmView=nil then
    frmView := TfrmView.Create(Self);
  rv.Receiver := frmView.RichView1;
end;

// Note 1: this event is called only as a result of successful drop
// Note 2: when dropping multiple files, OleBeforeDrop & OleAfterDrop is
//         called for each file
procedure TForm1.OleAfterDrop(Sender: TCustomRichView; X, Y: Integer;
  Format: TRVDragDropFormat; const Title: String);
begin
  rv.Receiver := nil;
  frmView.Caption := Title;
  frmView.Show;
  SetForegroundWindow(frmView.Handle);
  frmView := nil;
  AlphaBlendValue := 150;
end;

// Called after OleBeforeDrop instead of OleAfterDrop if the dropped data
// are not accepted
procedure TForm1.OleDropNotAccepted(Sender: TObject);
begin
  AlphaBlendValue := 150;
  frmView.Free;
  frmView := nil;
end;

procedure TForm1.OleEnter(Sender: TObject);
begin
  AlphaBlendValue := 200;
end;

procedure TForm1.OleLeave(Sender: TObject);
begin
  AlphaBlendValue := 150;
end;

// This event is not necessary in this demo
procedure TForm1.OleDragOver(Sender: TCustomRichView; X, Y: Integer;
  var CanDropHere: Boolean);
begin
  CanDropHere := True;
end;

{
initialization
  RegisterClass(TGifImage);
  RegisterClass(TPngObject);
  RV_RegisterPngGraphic(TPngObject);
}

end.
